pub enum NotificationError {
InvalidArgument(String),
NotifyError(Box<UStatus>),
}Expand description
An error indicating a problem with sending a notification to another uEntity.
Variants
InvalidArgument(String)
Indicates that the given message cannot be sent because it is not a valid Notification message.
NotifyError(Box<UStatus>)
Indicates an unspecific error that occurred at the Transport Layer while trying to send a notification.