#[non_exhaustive]pub enum PubSubError {
InvalidArgument(String),
PublishError(Box<UStatus>),
}Expand description
An error indicating a problem with publishing a message to a topic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidArgument(String)
Indicates that the given message cannot be sent because it is not a valid Publish message.
PublishError(Box<UStatus>)
Indicates an unspecific error that occurred at the Transport Layer while trying to publish a message.