Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct InMemoryRpcServer

pub struct InMemoryRpcServer<T, P> { /* private fields */ }
An RpcServer which keeps all information about registered endpoints in memory.

The server requires an implementations of UTransport for receiving RPC Request messages from clients and sending back RPC Response messages.

For each endpoint being registered, a UListener is created for the given request handler and registered with the underlying transport. The listener is also mapped to the endpoint’s method resource ID in order to prevent registration of multiple request handlers for the same method.

Implementations

Source

impl<T: UTransport, P: LocalUriProvider> InMemoryRpcServer<T, P>

pub fn new(transport: Arc<T>, uri_provider: Arc<P>) -> Self

Creates a new RPC server for a given transport.