Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct InMemorySubscriber

pub struct InMemorySubscriber<T, S, N> { /* private fields */ }
A Subscriber which keeps all information about registered subscription change handlers in memory.

The subscriber requires a (client) implementation of USubscription in order to inform the local USubscription service about newly subscribed and unsubscribed topics. It also needs a Notifier for receiving notifications about subscription status updates from the local USubscription service. Finally, it needs a UTransport for receiving events that have been published to subscribed topics.

During startup the subscriber uses the Notifier to register a generic UListener for receiving notifications from the USubscription service. The listener maintains an in-memory mapping of subscribed topics to corresponding subscription change handlers.

When a client subscribes to a topic, the local USubscription service is informed about the new subscription and a (client provided) subscription change handler is registered with the listener. When a subscription change notification arrives from the USubscription service, the corresponding handler is being looked up and invoked.

Implementations

Source

impl<T: UTransport + 'static, P: LocalUriProvider + 'static> InMemorySubscriber<T, RpcClientUSubscription, SimpleNotifier<T, P>>

pub async fn new( transport: Arc<T>, uri_provider: Arc<P>, ) -> Result<Self, RegistrationError>

Creates a new Subscriber for a given transport.

The subscriber keeps track of subscription change handlers in memory only. This function uses the given transport to create an crate::core::usubscription::RpcClientUSubscription and a crate::communication::SimpleNotifier and then delegate to Self::for_clients to create the Subscriber.

Errors

Returns an error if the Notifier cannot register a listener for notifications from the USubscription service.

Source

impl<T: UTransport, S: USubscription, N: Notifier> InMemorySubscriber<T, S, N>

pub async fn for_clients( transport: Arc<T>, usubscription: Arc<S>, notifier: Arc<N>, ) -> Result<Self, RegistrationError>

Creates a new Subscriber for given clients.

Arguments
  • transport - The transport to use for registering the event listeners for subscribed topics.
  • usubscription - The client to use for interacting with the (local) USubscription service.
  • notifier - The client to use for registering the listener for subscription updates from USubscription.
Errors

Returns an error if the Notifier cannot register a listener for notifications from the USubscription service.

pub async fn stop(&self) -> Result<(), RegistrationError>

Stops this client.

Clears all internal state and deregisters the listener for subscription updates from the USubscription service.

Errors

Returns an error if the listener could not be unregistered. In this case the internal state remains intact.