Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct UPayload

pub struct UPayload { /* private fields */ }
A wrapper around (raw) message payload data and the corresponding payload format.

Implementations

Source

impl UPayload

pub fn new<T: Into<Bytes>>(payload: T, payload_format: UPayloadFormat) -> Self

Creates a new payload for some data.

Examples
use up_rust::UPayloadFormat;
use up_rust::communication::UPayload;

let data: Vec<u8> = vec![0x00_u8, 0x01_u8, 0x02_u8];
let payload = UPayload::new(data, UPayloadFormat::Raw);
assert_eq!(payload.payload_format(), UPayloadFormat::Raw);
assert_eq!(payload.payload().len(), 3);
pub fn try_from_protobuf<T>(obj: T) -> Result<Self, UMessageError>

Creates a new UPayload from an object that can be mapped to/from a protobuf.

The resulting payload will have UPayloadType::UPAYLOAD_FORMAT_PROTOBUF_WRAPPED_IN_ANY.

Errors

Returns an error if the given message cannot be serialized to bytes.

Examples
use up_rust::{communication::UPayload, UPayloadFormat};
use protobuf::{well_known_types::wrappers::StringValue};

let mut data = StringValue::new();
data.value = "hello world".to_string();
assert!(UPayload::try_from_protobuf(data).is_ok_and(|pl|
    pl.payload_format() == UPayloadFormat::ProtobufWrappedInAny
        && pl.payload().len() > 0));
pub fn payload_format(&self) -> UPayloadFormat

Gets the payload format.

Returns

payload value of UPayload.

pub fn payload(&self) -> &Bytes

Gets the payload data.

pub fn extract_protobuf<T>(&self) -> Result<T, UMessageError>

Extracts the object that is contained in this message’s payload.

Type Parameters
  • T: The target type of the data to be unpacked.
Returns
  • The deserialized object contained in the payload.
Errors
Examples
use up_rust::{communication::UPayload, UPayloadFormat};
use protobuf::{well_known_types::wrappers::StringValue};

let mut data = StringValue::new();
data.value = "hello world".to_string();
let payload = UPayload::try_from_protobuf(data).expect("should be able to create UPayload from StringValue");

let string_value: StringValue = payload.extract_protobuf().expect("should be able to extract StringValue from UPayload");
assert_eq!(string_value.value, *"hello world");