Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Trait SubscriptionChangeHandler

pub trait SubscriptionChangeHandler: Send + Sync {
    // Required method
    fn on_subscription_change(
        &self,
        topic: UUri,
        new_status: SubscriptionStatus,
    );
}
Callback invoked when a subscription’s status changes.

Required Methods

fn on_subscription_change(&self, topic: UUri, new_status: SubscriptionStatus)

Invoked for each update to the subscription status for a given topic.

Implementations must not block the current thread.

Arguments
  • topic - The topic for which the subscription status has changed.
  • status - The new status of the subscription.

Implementors

Source

impl SubscriptionChangeHandler for MockSubscriptionChangeHandler

Callback invoked when a subscription’s status changes.