pub struct InMemoryRpcServer<T, P> { /* private fields */ }Expand description
An RpcServer which keeps all information about registered endpoints in memory.
The server requires an implementations of UTransport for receiving RPC Request messages
from clients and sending back RPC Response messages.
For each endpoint being registered, a UListener is created for
the given request handler and registered with the underlying transport. The listener is also
mapped to the endpoint’s method resource ID in order to prevent registration of multiple
request handlers for the same method.
Implementations
Sourceimpl<T: UTransport, P: LocalUriProvider> InMemoryRpcServer<T, P>
impl<T: UTransport, P: LocalUriProvider> InMemoryRpcServer<T, P>