pub trait SubscriptionChangeHandler: Send + Sync {
// Required method
fn on_subscription_change(
&self,
topic: UUri,
new_status: SubscriptionStatus,
);
}Expand description
Callback invoked when a subscription’s status changes.
Required Methods
Sourcefn on_subscription_change(&self, topic: UUri, new_status: SubscriptionStatus)
fn on_subscription_change(&self, topic: UUri, new_status: SubscriptionStatus)
Invoked for each update to the subscription status for a given topic.
Implementations must not block the current thread.
Arguments
topic- The topic for which the subscription status has changed.status- The new status of the subscription.
Implementors
impl SubscriptionChangeHandler for MockSubscriptionChangeHandler
Callback invoked when a subscription’s status changes.